@@ -96,7 +96,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nmap_error.h 6858 2008-02-28 18:52:06Z fyodor $ */
+/* $Id: nmap_error.h 7220 2008-04-28 17:53:32Z kris $ */
 
 #ifndef NMAP_ERROR_H
 #define NMAP_ERROR_H
@@ -106,7 +106,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "nmap_config.h"
 #else
 #ifdef WIN32
 #include "nmap_winconfig.h"
